durationtools.rational_to_equal_or_greater_assignable_rational
==============================================================

.. autofunction:: abjad.tools.durationtools.rational_to_equal_or_greater_assignable_rational.rational_to_equal_or_greater_assignable_rational
